Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(890)

Unified Diff: chrome/browser/chromeos/gdata/gdata_download_observer.cc

Issue 10828385: Rename DocumentsServiceInterface to DriveServiceInterface. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: rebase. Created 8 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/chromeos/gdata/gdata_download_observer.cc
diff --git a/chrome/browser/chromeos/gdata/gdata_download_observer.cc b/chrome/browser/chromeos/gdata/gdata_download_observer.cc
index 07bbad68f69826fc7104658350d7372c07012856..c91fa3c6eb4ec990dbc75ddec99acb185ddc53c7 100644
--- a/chrome/browser/chromeos/gdata/gdata_download_observer.cc
+++ b/chrome/browser/chromeos/gdata/gdata_download_observer.cc
@@ -7,7 +7,7 @@
#include "base/callback.h"
#include "base/file_util.h"
#include "base/supports_user_data.h"
-#include "chrome/browser/chromeos/gdata/documents_service_interface.h"
+#include "chrome/browser/chromeos/gdata/drive_service_interface.h"
#include "chrome/browser/chromeos/gdata/gdata.pb.h"
#include "chrome/browser/chromeos/gdata/gdata_file_system_interface.h"
#include "chrome/browser/chromeos/gdata/gdata_system_service.h"
@@ -15,6 +15,7 @@
#include "chrome/browser/chromeos/gdata/gdata_uploader.h"
#include "chrome/browser/chromeos/gdata/gdata_util.h"
#include "chrome/browser/chromeos/gdata/gdata_wapi_parser.h"
+#include "chrome/browser/chromeos/gdata/gdata_wapi_service.h"
kochi 2012/08/21 02:34:51 Looks like an unnecessary header sneaked in. Remov
#include "chrome/browser/download/download_completion_blocker.h"
#include "chrome/browser/profiles/profile_manager.h"
#include "net/base/net_util.h"
@@ -151,7 +152,7 @@ void OnEntryFound(Profile* profile,
}
}
// Callback for DocumentsServiceInterface::Authenticate.
void OnAuthenticate(Profile* profile,
const FilePath& gdata_path,
const base::Closure& substitute_callback,
@@ -216,11 +217,11 @@ void GDataDownloadObserver::SubstituteGDataDownloadPath(Profile* profile,
if (util::IsUnderGDataMountPoint(gdata_path)) {
// Can't access drive if we're not authenticated.
// We set off a chain of callbacks as follows:
- // DocumentsServiceInterface::Authenticate
+ // DriveServiceInterface::Authenticate
// OnAuthenticate calls GDataFileSystem::GetEntryInfoByPath
// OnEntryFound calls GDataFileSystem::CreateDirectory (if necessary)
// OnCreateDirectory calls SubstituteGDataDownloadPathInternal
- GetSystemService(profile)->docs_service()->Authenticate(
+ GetSystemService(profile)->drive_service()->Authenticate(
base::Bind(&OnAuthenticate, profile, gdata_path,
base::Bind(&SubstituteGDataDownloadPathInternal,
profile, callback)));
@@ -151,7 +152,7 @@ void OnEntryFound(Profile* profile,
}
}
-// Callback for DocumentsServiceInterface::Authenticate.
+// Callback for DriveServiceInterface::Authenticate.
void OnAuthenticate(Profile* profile,
const FilePath& gdata_path,

Powered by Google App Engine
This is Rietveld 408576698